@@ -1,42 +1,40 @@
 app_driver_tm_data_table <- function() {
   init_teal_app_driver(
-    data = simple_teal_data(),
-    modules = tm_data_table(
-      label = "Data Table",
-      variables_selected = list(
-        iris = c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width", "Species")
-      ),
-      datanames = c("iris", "mtcars"),
-      dt_args = list(caption = "Table Caption"),
-      dt_options = list(
-        searching = FALSE, pageLength = 30, lengthMenu = c(5, 15, 30, 100),
-        scrollX = TRUE
-      ),
-      server_rendering = FALSE,
-      pre_output = NULL,
-      post_output = NULL
+    teal::init(
+      data = simple_teal_data(),
+      modules = tm_data_table(
+        label = "Data Table",
+        variables_selected = list(
+          iris = c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width", "Species")
+        ),
+        datanames = c("iris", "mtcars"),
+        dt_args = list(caption = "Table Caption"),
+        dt_options = list(
+          searching = FALSE, pageLength = 30, lengthMenu = c(5, 15, 30, 100),
+          scrollX = TRUE
+        ),
+        server_rendering = FALSE,
+        pre_output = NULL,
+        post_output = NULL
+      )
     ),
-    timeout = 3000
+    timeout = 10000
   )
 }
 
 test_that("e2e - tm_data_table: Initializes without errors", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_data_table()
 
   app_driver$expect_no_shiny_error()
 
-  testthat::expect_equal(
-    app_driver$get_text("#teal-teal_modules-active_tab .active"),
-    "Data Table"
-  )
+
+  testthat::expect_equal(app_driver$get_text(".teal-modules-tree .active"), "Data Table")
 
   app_driver$stop()
 })
 
 test_that("e2e - tm_data_table: Verify checkbox displayed over data table", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_data_table()
 
@@ -46,16 +44,15 @@ test_that("e2e - tm_data_table: Verify checkbox displayed over data table", {
 })
 
 test_that("e2e - tm_data_table: Verify module displays data table", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_data_table()
 
   # table
   testthat::expect_match(app_driver$get_active_module_output("iris-data_table"), "Table Caption")
-  testthat::expect_true(app_driver$is_visible(selector = app_driver$active_module_element("iris-data_table")))
+  testthat::expect_true(app_driver$is_visible(selector = app_driver$namespaces(TRUE)$module("iris-data_table")))
 
   extract_iris_table <- function() {
-    app_driver$active_module_element("iris-data_table") %>%
+    app_driver$namespaces(TRUE)$module("iris-data_table") %>%
       app_driver$get_html_rvest() %>%
       rvest::html_table(fill = TRUE) %>%
       .[[2]] %>%
@@ -83,7 +80,6 @@ test_that("e2e - tm_data_table: Verify module displays data table", {
 })
 
 test_that("e2e - tm_data_table: Verify default variable selection and set new selection", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_data_table()
 
