@@ -5,33 +5,31 @@ app_driver_tm_front_page <- function() {
   })
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_front_page(
-      label = "Front page",
-      datanames = "all",
-      header_text = c(
-        "Important information" = "It can go here.",
-        "Other information" = "Can go here."
-      ),
-      tables = list("MTCARS" = head(mtcars, 5), "IRIS" = head(iris, 5)),
-      additional_tags = HTML("Additional HTML or shiny tags go here"),
-      footnotes = "This is a footnote"
+    teal::init(
+      data = data,
+      modules = tm_front_page(
+        label = "Front page",
+        datanames = "all",
+        header_text = c(
+          "Important information" = "It can go here.",
+          "Other information" = "Can go here."
+        ),
+        tables = list("MTCARS" = head(mtcars, 5), "IRIS" = head(iris, 5)),
+        additional_tags = HTML("Additional HTML or shiny tags go here"),
+        footnotes = "This is a footnote"
+      )
     ),
-    timeout = 3000
+    timeout = 10000
   )
 }
 
 test_that("e2e - tm_front_page: Initializes without errors and check html elements", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_front_page()
 
   app_driver$expect_no_shiny_error()
 
-  testthat::expect_equal(
-    app_driver$get_text("#teal-teal_modules-active_tab .active"),
-    "Front page"
-  )
+  testthat::expect_equal(app_driver$get_text(".teal-modules-tree .active"), "Front page")
 
   # header text
   testthat::expect_match(
@@ -47,26 +45,28 @@ test_that("e2e - tm_front_page: Initializes without errors and check html elemen
 })
 
 test_that("e2e - tm_front_page: Verify the module displays tables", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_front_page()
   # tables
   testthat::expect_match(app_driver$get_active_module_output("table_1"), "MTCARS")
-  testthat::expect_true(app_driver$is_visible(sprintf("%s table", app_driver$active_module_element("table_1"))))
+  testthat::expect_true(app_driver$is_visible(app_driver$namespaces(TRUE)$module("table_1 table")))
 
   testthat::expect_match(app_driver$get_active_module_output("table_2"), "IRIS")
-  testthat::expect_true(app_driver$is_visible(sprintf("%s table", app_driver$active_module_element("table_2"))))
+  testthat::expect_true(app_driver$is_visible(app_driver$namespaces(TRUE)$module("table_2 table")))
   app_driver$stop()
 })
 
 test_that("e2e - tm_front_page: Verify the module displays metadata", {
-  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_front_page()
 
   # show metadata
-  app_driver$click(NS(app_driver$active_module_ns(), "metadata_button"))
-  testthat::expect_true(app_driver$is_visible(sprintf("%s table", app_driver$active_module_element("metadata_table"))))
+  app_driver$click(app_driver$namespaces()$module("metadata_button"))
+  testthat::expect_true(
+    app_driver$is_visible(
+      app_driver$namespaces(TRUE)$module("metadata_table table")
+    )
+  )
 
   app_driver$stop()
 })
